@@ -63,6 +63,9 @@ char yk[];
       if(strcmp(gobi, "") == 0){
 	strcpy(gobi, "( 2)");	goto LAST2;
       }
+      if(strcmp(gobi, "") == 0){
+	strcpy(gobi, "( 2)");	goto LAST2;
+      }
       if(strcmp(gobi, "s") == 0){
 	strcpy(gobi, "s( 2)");	goto LAST2;
       }
@@ -339,7 +342,8 @@ char md[];
       }
     gobi += 2;
     if(strcmp(gobi, "") == 0){ strcpy(gobi, "");	goto RTN; }
-    if(strcmp(gobi, "") == 0 || strcmp(gobi, "") == 0){
+    if(strcmp(gobi, "") == 0 || strcmp(gobi, "") == 0
+    || strcmp(gobi, "") == 0){
       strcpy(gobi, "");	goto RTN;
     }
     if(strcmp(gobi, "") == 0){ strcpy(gobi, "");	goto RTN; }
@@ -464,7 +468,8 @@ char yk[];
       if(strcmp(gobi, shs[i]) == 0){
 	strcpy(gobi, mzn[i]);	strcat(yk, "Ȃ");	return;
       }
-    strcat(yk, "̂ł͂Ȃ");
+    //    strcat(yk, "̂ł͂Ȃ");
+    strcat(yk, "Ƃ͂Ȃ");
 }
 
 gimu(mr)
@@ -546,11 +551,17 @@ char md[];
     }
     if(index(md, '(')) sw = 1;	else sw = 0;
     genkei(md);
+ if(Dbg == 'Y') fprintf(dbg, "--- saser --- md = %s \n", md);
     ln = strlen(md);
     if(ln > 3){
       if(strcmp(md, "3") == 0){
 	strcpy(md, "3点");	goto RTN;
       }
+      gobi = md+ln-6;
+      if(strcmp(gobi, "ł") == 0){
+	strcpy(gobi, "ɂ");
+	goto RTN;
+      }
       gobi = md+ln-4;
       if(strcmp(gobi, "") == 0 || strcmp(gobi, "Ȃ") == 0){
 	if(sw == 1) strcpy(gobi, "Ă炤");
@@ -620,6 +631,9 @@ char mr[];
     if(ln > 3 && strcmp(gobi-4, "") == 0){
       strcpy(gobi-4, "܂");	goto RTN;
     }
+    if(ln > 12 && strcmp(gobi-12, "( 2)") == 0){
+      strcpy(gobi-12, "܂");	goto RTN;
+    }
     for(i = 0; i <= 31; i++){
       strcpy(k, ksm[i]);
       if(ln > 3 && strcmp(gobi-4, k) == 0){
@@ -810,8 +824,9 @@ char kaz[40];
 {
     char bj[100];
     strcpy(bj, md[i]);
+    kaz[2] = '\0';  // 15/9/30
     strcat(bj, kaz);
-    if(kaz[0] != '\0') strcat(bj, "");
+    //    if(kaz[0] != '\0') strcat(bj, "");
     strcpy(md[i],bj);
 }
 
@@ -829,7 +844,7 @@ char str[];
     if(strcmp(jos, "")==0 || strcmp(jos, "")==0 || strcmp(jos, "")==0
       || strcmp(jos, "") == 0
       || strcmp(jos, "")==0 && instr(str, "ł") != 2
-      || strcmp(jos, "")==0 && instr(str, "ƂĂ") != 2 )
+       || strcmp(jos, "")==0 && instr(str, "ƂĂ") != 2  && strncmp(str+1, "Ƃ킯", 8) )
        ptcut(str+i, 2);
 }
 
