@@ -508,9 +508,12 @@ char mdi[], mzi[], mdj[], mzj[];
     if(Dbg == 'Y') fprintf(dbg, "--- ninsyo --- 4  %s \n", mdi+1);
         if(strstr(mzi, "") || strchr(mzi,'x') ) return;
         if(strncmp(mdj+1, "1 ", 2) == 0 || strcmp(mdj+1, "1") == 0) return;
-        if(strncmp(mdi+1, "sheep", 5) == 0 || strncmp(mdi+1, "deer", 4) == 0
-        || strncmp(mdi+1, "Japanese", 8) == 0 || strncmp(mdi+1, "%", 1) == 0
-        || strncmp(mdi+1, "yen", 3) == 0
+	//`P̃`FbN
+	if(fukuchk(mdi+1) == 1) return;
+	//ؕ
+        if(ispunct(*(mdi+1)) ||
+         strncmp(mdi+1, "Japanese", 8) == 0 || strncmp(mdi+1, "%", 1) == 0
+	   || strncmp(mdi+1, "yen", 3) == 0 // || strncmp(mdi+1, "(", 1) == 0
         || strncmp(mdi+1, "o'clock", 7) == 0) return;
 	// mdi+1̍ŏ̒Pplu猟v炻̕`Pɒu^[
 	if(irregPlu(mdi+1) == 1) return;
@@ -533,11 +536,12 @@ char mdi[], mzi[], mdj[], mzj[];
         else if(strlen(mdi+1)!=0) ptinsert(pt, "s");
 
     }
-    else{
+    else{ //P
       if(strncmp(mdi+1, "the", 3) == 0 || strncmp(mdi+1, "someone", 7) == 0
+      || strncmp(mdi+1, "to ", 3) == 0
       || strncmp(mdi+1, "all", 3) == 0) return;
       if(strchr(mzi, 'K') || strstr(mdj+1, " and ") ) return;
-//  printf("--- ninsho --- mdi = %s mzi = %s \n", mdi, mzi);
+//  printf("--- ninsyo --- mdi = %s mzi = %s \n", mdi, mzi);
       if(strncmp(mdi+1, "a ", 2) == 0 || strncmp(mdi+1, "an ", 3) == 0) return;
       if(strchr("aiueo", *(mdi+1))){
         ptinsert(mdi+1, "an ");
@@ -1212,12 +1216,25 @@ char kaz[30];
     char bj[100], *pt;
     strcpy(bj, md[i]);
     pt = strchr(bj, '\0');
-    if(strncmp(bj+1, "Japanese", 8) == 0) return;
+    if(fukuchk(bj+1) == 1) return;
     if(*(pt-1) == 'y') strcpy(pt-1, "ies");
     else strcat(bj, "s");
     strcpy(md[i],bj);
 }
 
+int fukuchk(wd)
+char *wd;
+{
+  if( // P
+     strncmp(wd, "Japanese", 8) == 0 || strncmp(wd, "sheep", 5) == 0 ||
+     strncmp(wd, "deer", 4) == 0 || strncmp(wd, "fish", 4) == 0 ||
+     // łɕ̖
+     strncmp(wd, "childen", 7) == 0 || strncmp(wd, "teeth", 5) == 0 ||
+     strncmp(wd, "women", 5) == 0 || strncmp(wd, "mice", 4) == 0 ||
+     strncmp(wd, "feet", 4) == 0 || strncmp(wd, "men", 3) == 0 ) return 1;
+  return 0;
+}
+
 irregPlu(wd) // wd̒P
 char *wd;
 {
