@@ -92,8 +92,12 @@ char *argv[];
       fprintf(fpout, "%s", egs);
       if(*egs != '<' || strstr(egs, "-->")) fprintf(fpout, "\n", egs);
     }
-    if(Dbg == 'Y') fclose(dbg);
-    if(LOG == 'Y') fclose(prcs);
+    if(Dbg == 'Y'){ fclose(dbg);
+       system("nkf --windows --overwrite DEBUG.J2E");
+    }
+    if(LOG == 'Y'){ fclose(prcs);
+       system("nkf --windows --overwrite PROCESS.J2E");
+    }
     fclose(jed);
     fclose(fpout);
     fclose(fpin); 
@@ -287,13 +291,14 @@ Jap2Eng(){
         strcpy(wdx, jwd);    goto JMP;
       }
       wdx[0] = '\0';
+        zkc[0] = '\0';
       preEdit();
       if(strcmp(wdx, "(exit)") == 0) goto JMP1;
 
       for(i = 0; ;i++ ){
         if(i >= 20) error("word cann't be searched !");
 	if(wdx[0] != '\0') break;
-        zkc[0] = '\0';
+	//        zkc[0] = '\0'; // 16/5/16
 	preConj();  // 16/3/31
         if(strcmp(wdx, "(exit)") == 0) goto JMP1;
 
